<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Er is leven buiten de browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versie %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Gelicenseerd aan: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 is gratis software, maar de ontwikkeling ervan vergt kostbare tijd.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Doneer&lt;/a&gt; om bij te dragen aan de verdere ontwikkeling van %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Vertaal %1 naar uw moedertaal met behulp van %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Pictogram ontworpen door %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Uitgebracht onder de &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vul uw licentie-details in</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mailadres:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Code:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Alstublieft, Licenceer  %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Deze demo is verlopen.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>De volledige versie stelt u in staat om video&apos;s te bekijken zonder onderbrekingen.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Zonder een licentie zal deze applicatie vervallen in %1 dagen.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Door dit produkt te kopen beloon je mij voor het harde werk dat ik geïnvesteerd heb in het maken van %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Gebruik de demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vul licentie in</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Koop licentie</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>D.m.v. %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alle video&apos;s</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Niet-bekeken video&apos;s</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Laatst bijgewerkt</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Laatst toegevoegd</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Laatst bekeken</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Vaakst bekeken</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sorteer op</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Markeer alles als bekeken</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Toon bijgewerkte</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>U heeft geen abonnementen. Gebruik het ster-symbool om te abonneren op kanalen.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alle video&apos;s</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Niet-bekeken video&apos;s</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Markeren als bekeken</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Abonnement opzeggen</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Er zijn op dit moment geen bijgewerkte abonnementen.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Zojuist</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 bekeken</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>seconden</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 resterend</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 gedownload in %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Download greed</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Verander locatie...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Kies de downloadlocatie</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Downloadlocatie aangepast.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Huidige downloads zullen in de vorige locatie worden geplaatst.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Downloaden naar:%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Het uitvoerbare bestand is aangepast, misschien door een virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 kan niet starten. Probeer opnieuw te installeren.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Herinstalleren</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Speel af</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeer</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Speel af/Pauzeer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stop afspelen na huidig nummer</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Volgend nummer</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Vorig nummer</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Verhoog volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Verlaag volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Demp</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Spoel naar voren</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Spoel naar achteren</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Vind video&apos;s en kanalen d.m.v. sleutelwoord</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Blader</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Blader video&apos;s d.m.v. categorie</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnementen</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanaal-abonnementen</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Maak het u zelf gemakkelijk</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimaliseer</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stop het afspelen en keer terug naar het zoekvenster</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>V&amp;orige</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ga terug naar het vorige nummer</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Sla over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Spoel door naar de volgende vieo</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Speel af</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Hervat afspelen</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Schakel over naar Volledig scherm</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Compacte modus</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Verberg de afspeellijst en de werkbalk</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Open de &amp;Youtube-pagina</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ga naar de YouTube-videopagina en pauzeer het afspelen</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopieer de YouTube-&amp;link</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopieer de huidige YouTube-link naar het klembord</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopieer de videostream-&amp;URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopieer de huidige videostream-URL naar het klembord</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Vind video&amp;fragmenten</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Vind gerelateerde videofragmenten, hopelijk in de juiste volgorde</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Verwijder</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Verwijder de geselecteerde video&apos;s uit de afspeellijst</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Verplaats &amp;omhoog</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Verplaats de geselecteerde video&apos;s in de afspeellijst naar boven</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Verplaats &amp;omlaag</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Verplaats de geselecteerde video&apos;s in de afspeelijst naar beneden</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Wis recente zoekopdrachten</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Wis de zoek geschiedenis. Dit kan niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sluit af</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tot ziens</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 op het internet</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Geef een &amp;donatie</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Ondersteun alstublieft de ontwikkeling van %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informatie over %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Demp volume</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Speel handmatig af</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Speel handmatig video&apos;s af</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Downloads</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Geef details weer van videodownloads</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Download</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Download de huidige video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Screenshot &amp;nemen</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Abonneer op kanaal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Deel de huidige video door middel van %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sluit</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Zweef erboven</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stop na deze video</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Rapporteer een Probleem...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Verfijn Zoekopdracht...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Meer...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Gerelateerde video&apos;s</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Bekijk video&apos;s gerelateerd aan de huidige</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Open in &amp;browser...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>&amp;Menubalk weergeven/verbergen</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>Vindt u %1 te &amp;gek? Waardeer het!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Koop %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Programma</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Afspeelopties</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Afspeellijst</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Deel</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Weergave</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Druk op %1 om het volume te verhogen, op %2 om het te verlagen</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Kies uw inhoudslocatie</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Bezig met openen van %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Wilt u %1 afsluiten terwijl er een download bezig is?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Als u nu %1 afsluit, zal de download worden beëindigd.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Sluit en annuleer het downloaden</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Wacht tot het downloaden is voltooid</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fout: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeer</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pauzeer afspelen</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Verlaat &amp;volledig scherm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Resterende tijd: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume op %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume is gedempt</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume is niet gedempt</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maximale videokwaliteit staat op %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Uw privacy is nu gewaarborgd</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Downloads afgerond</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versie %2 nu beschikbaar.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Herinner mij later</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Werk bij</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>U kunt de menubalk nog steeds benaderen door op ALT te drukken</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>U kunt nu uw YouTube-link kopieren naar een ander programma</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>U kunt nu uw videostream-URL kopieren naar een ander programma</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>De link zal maar een beperkte tijd geldig zijn.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Bezig met downloaden van %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>van</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>fragment</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>aflevering</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Verstuurd vanaf %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Zeg abonnement op van %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Abonneer op %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Een nieuwe versie van %1 is beschikbaar!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 is nu beschikbaar. U heeft %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Wilt u deze nu downloaden?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Sla deze versie over</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Herinner me later</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installeer update</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 van %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Aan het voorbereiden</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Gestopt</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Stop het downloaden</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Toon in %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Open oudermap</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Herstart het downloaden</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Toon %1 meer</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Geen video&apos;s</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Geen video&apos;s meer</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sorteer op</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevantie</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Weergaven</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Waardering</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Elke Periode</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Dagen</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Dagen</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Gemiddeld</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Minder dan 4 minuten</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Tussen 4 en 20 minuten</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Langer dan 20 minuten</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kwaliteit</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>HD Resolutie </translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p of hover</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Welkom bij &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>om te beginnen met het bekijken van video&apos;s.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>een zoekwoord</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Recente zoekwoorden</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Recente kanalen</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Verkrijg de volledige versie</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Terug</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Spoel vooruit naar %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Spoel terug naar %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Verfijn Zoekopdracht</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Bedoelde je: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Verander locatie...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Screenshot opgeslagen in %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Screenshots-locatie veranderd.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Meest populair</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Bezig met downloaden van update...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Downloaden van %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algerije</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentinië</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australië</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>België</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazilië</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chili</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tsjechië</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypte</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankrijk</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Duitsland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Griekenland</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hongarije</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesië</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ierland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israël</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italië</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanië</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Maleisië</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nederland</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nieuw-Zeeland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipijnen</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saoedi-Arabië</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Zuid-Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Zuid-Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Zweden</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunesië</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turkije</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Oeganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Verenigde Emiraten</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Verenigd Koninkrijk</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Wereldwijd</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan de videostream niet verkrijgen voor %1</translation>
    </message>
</context>
</TS>